@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KITINERARY_TAXI_H
-#define KITINERARY_TAXI_H
+#pragma once
 
 #include "kitinerary_export.h"
 #include "datatypes.h"
@@ -26,4 +25,3 @@ private:
 
 Q_DECLARE_METATYPE(KItinerary::Taxi)
 
-#endif // KITINERARY_TAXI_H
