@@ -25,7 +25,7 @@ class TrainStationIndex : public UnalignedNumber<2> {
     using UnalignedNumber<2>::UnalignedNumber;
 };
 
-/** Train station id to station index lookup table strcuture. */
+/** Train station id to station index lookup table structure. */
 template <typename T>
 struct TrainStationIdIndex {
     constexpr bool operator<(const TrainStationIdIndex &other) const
@@ -47,8 +47,6 @@ struct TrainStationIdIndex {
 struct TrainStation {
     Coordinate coordinate;
     CountryId country;
-
-    KITINERARY_EXPORT Tz timezone() const;
 };
 
 
